@@ -1,14 +1,14 @@
-// Define to the name of the distribution.
-#undef PACKAGE
+// acconfig.h symbols and macros for libstdc++ v3 -*- C++ -*-
 
-// Define to the version of the distribution. 
-#undef VERSION
+// If using the namespace std, you need this. Eventually this should
+// not be an option. In the meantime, and as things like std_ctype.h
+// need to be hacked out, give people the option. If this is set to 1,
+// CXXFLAGS should include -fhonor-std. If this is undefined, CXXFLAGS
+// should include -fno-honor-std.
+#undef _GLIBCPP_USE_NAMESPACES
 
-// Define if <complex.h> is ISO C 9x compliant.
-#undef HAVE_COMPLEX_H
-
-// Define if LC_MESSAGES is available in <locale.h>.
-#undef HAVE_LC_MESSAGES
+// Include support for 'long long' and 'unsigned long long'.
+#undef _GLIBCPP_USE_LONG_LONG
 
 // Define if the host has a type mbstate_t defined in
 // wchar.h, as required by 21.1.3.1. Some systems, namely
@@ -16,9 +16,13 @@
 // around.
 #undef _GLIBCPP_NEED_MBSTATE_T
 
-// Define if <cctype> uses the _ISBit macro to define what constitutes
-// a space, punct, etc. Usually, this involved _ISspace, etc macros.
-#undef _GLIBCPP_USE_CTYPE_ISBIT
+// Define if WCHAR_MIN and WCHAR_MAX are in the <cwchar_t>
+// header. Presently, this is needed so that solaris won't
+// instantitate numeric_limits<wchar_t>
+#undef _GLIBCPP_HAS_WCHAR_MIN_MAX
+
+// Define if code specialized for wchar_t should be used.
+#undef _GLIBCPP_USE_WCHAR_T
 
 // Define if the compiler/host combination has __builtin_sinf defined.
 #undef _GLIBCPP_HAS_BUILTIN_SINF
@@ -32,6 +36,21 @@
 // Define if the compiler/host combination has __builtin_fabsf defined.
 #undef _GLIBCPP_HAS_BUILTIN_SQRTF
 
+// Define if GCC support for __complex__ float is buggy.
+#undef _GLIBCPP_BUGGY_FLOAT_COMPLEX
+
+// Define if GCC support for __complex__ is buggy.
+#undef _GLIBCPP_BUGGY_COMPLEX
+
+// Define if LC_MESSAGES is available in <locale.h>.
+#undef HAVE_LC_MESSAGES
+
+// Define if <float.h> exists.
+#undef HAVE_FLOAT_H
+
+// Define if modf is present in <math.h>
+#undef HAVE_MODF
+
 // @BOTTOM@
 //
 // Systems that have certain non-standard functions prefixed with an
