@@ -1,6 +1,6 @@
 // The template and inlines for the -*- C++ -*- complex number classes.
 
-// Copyright (C) 1997-1999 Cygnus Solutions
+// Copyright (C) 1997-1999 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -140,6 +140,9 @@ namespace std
         typedef float value_type;
 
         complex(float = 0.0f, float = 0.0f);
+#ifdef _GLIBCPP_BUGGY_COMPLEX
+	complex(const complex& __z) : _M_value(__z._M_value) {}
+#endif
         explicit complex(const complex<double>&);
         explicit complex(const complex<long double>&);
 
@@ -216,6 +219,9 @@ namespace std
         typedef double value_type;
 
         complex(double  =0.0, double =0.0);
+#ifdef _GLIBCPP_BUGGY_COMPLEX
+	complex(const complex& __z) : _M_value(__z._M_value) {}
+#endif
         complex(const complex<float>&);
         explicit complex(const complex<long double>&);
         
@@ -291,6 +297,9 @@ namespace std
         typedef long double value_type;
 
         complex(long double = 0.0L, long double = 0.0L);
+#ifdef _GLIBCPP_BUGGY_COMPLEX
+	complex(const complex& __z) : _M_value(__z._M_value) {}
+#endif
         complex(const complex<float>&);
         complex(const complex<double>&);
 
