@@ -1,6 +1,6 @@
 // String based streams -*- C++ -*-
 
-// Copyright (C) 1997-1999 Cygnus Solutions
+// Copyright (C) 1997-1999 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -42,6 +42,8 @@ namespace std {
   template<typename _CharT, typename _Traits, typename _Alloc>
     class basic_stringbuf : public basic_streambuf<_CharT, _Traits>
     {
+    public:
+
       // Types:
       typedef _CharT 					char_type;
       typedef typename _Traits::int_type 		int_type;
@@ -53,10 +55,13 @@ namespace std {
       typedef basic_string<_CharT, _Traits, _Alloc> 	__string_type;
       typedef __string_type::size_type			__size_type;
 
+    private:
+
       // Data Members:
       __string_type 		_M_string;
       
     public:
+
       // Constructors:
       explicit 
       basic_stringbuf(ios_base::openmode __mode = ios_base::in | ios_base::out)
@@ -83,7 +88,7 @@ namespace std {
 	    // current stringbuf internal buffer.
 	    __size_type __len = _M_string.size();
 	    if (_M_out_cur > _M_out_beg)
-	      __len = max(__size_type(_M_out_cur - _M_out_beg), __len);
+	      __len = max(__size_type(_M_out_end - _M_out_beg), __len);
 	    return __string_type(_M_out_beg, _M_out_beg + __len);
 	  }
       }
@@ -106,16 +111,19 @@ namespace std {
 	// necessary as ostringstreams are implemented with the
 	// streambufs having control of the allocation and
 	// re-allocation of the internal string object, _M_string.
-	_M_buf_size = _M_string.capacity();
+	_M_buf_size = _M_string.size();
 	_M_mode = __mode;
-	_M_really_sync(0, 0); 
+	if (_M_mode & ios_base::ate)
+	  _M_really_sync(0, _M_buf_size); 
+	else  
+	  _M_really_sync(0, 0); 
       }
 
       // Overridden virtual functions:
       virtual int_type 
       underflow()
       {
-	if (_M_in_cur != _M_in_end)
+	if (_M_in_cur && _M_in_cur < _M_in_end)
 	  return traits_type::to_int_type(*gptr());
 	else
 	  return traits_type::eof();
@@ -146,23 +154,27 @@ namespace std {
       seekpos(pos_type __sp, 
 	      ios_base::openmode __mode = ios_base::in | ios_base::out);
 
-      // Internal function for correctly tracking the internal string
-      // buffer, and correctly computing offsets immediately after the
-      // internal string object has been resized. Assumes that
-      // _M_buf_size refers to the capacity of the newly-allocated
-      // _M_string (and thus the internal buffer), and that __ilen and
-      // __olen refer to the offsets between the beginning of the
-      // buffer and the _M_[in,out]_cur pointers.
+      // Internal function for correctly updating the internal buffer
+      // for a particular _M_string, due to initialization or
+      // re-sizing of an existing _M_string.
+      // Assumes: contents of _M_string and internal buffer match exactly.
+      // __i == _M_in_cur - _M_in_beg      
+      // __o == _M_out_cur - _M_out_beg
       virtual int 
-      _M_really_sync(__size_type __ilen, __size_type __olen)
+      _M_really_sync(__size_type __i, __size_type __o)
       {
 	char_type* __base = const_cast<char_type*>(_M_string.data());
-	if (_M_mode & ios_base::in)
-	  this->setg(__base, __base + __ilen, __base + _M_buf_size);
-	if (_M_mode & ios_base::out)
+	bool __testin = _M_mode & ios_base::in;
+	bool __testout = _M_mode & ios_base::out;
+	__size_type __len = _M_string.size();
+
+	_M_buf = __base;
+	if (__testin)
+	    this->setg(__base, __base + __i, __base + __len);
+	if (__testout)
 	  {
-	    this->setp(__base, __base + _M_buf_size);
-	    _M_out_cur += __olen;
+	    this->setp(__base, __base + __len);
+	    _M_out_cur += __o;
 	  }
 	return 0;
       }
@@ -176,6 +188,8 @@ namespace std {
   template<typename _CharT, typename _Traits, typename _Alloc>
     class basic_istringstream : public basic_istream<_CharT, _Traits>
     {
+    public:
+
       // Types:
       typedef _CharT char_type;
       typedef typename _Traits::int_type 		int_type;
@@ -188,7 +202,6 @@ namespace std {
       typedef basic_stringbuf<_CharT, _Traits, _Alloc> 	__stringbuf_type;
       typedef basic_istream<_CharT, _Traits>		__istream_type;
 
-    public:
       // Constructors:
       explicit 
       basic_istringstream(ios_base::openmode __mode = ios_base::in)
@@ -218,7 +231,7 @@ namespace std {
   
       void 
       str(const __string_type& __s)
-      { return rdbuf()->str(__s); }
+      { rdbuf()->str(__s); }
 
     };
 
@@ -229,6 +242,8 @@ namespace std {
   template <typename _CharT, typename _Traits, typename _Alloc>
     class basic_ostringstream : public basic_ostream<_CharT, _Traits>
     {
+    public:
+
       // Types:
       typedef _CharT char_type;
       typedef typename _Traits::int_type int_type;
@@ -240,7 +255,6 @@ namespace std {
       typedef basic_stringbuf<_CharT, _Traits, _Alloc> 	__stringbuf_type;
       typedef basic_ostream<_CharT, _Traits>		__ostream_type;
 
-    public:
       // Constructors/destructor:
       explicit 
       basic_ostringstream(ios_base::openmode __mode = ios_base::out)
@@ -270,7 +284,7 @@ namespace std {
  
       void 
       str(const __string_type& __s)
-      { return rdbuf()->str(__s); }
+      { rdbuf()->str(__s); }
 
     };
   
@@ -282,6 +296,7 @@ namespace std {
     class basic_stringstream : public basic_iostream<_CharT, _Traits>
     {
     public:
+
       // Types
       typedef _CharT char_type;
       typedef typename _Traits::int_type int_type;
@@ -324,7 +339,7 @@ namespace std {
 
       void 
       str(const __string_type& __s)
-      { return rdbuf()->str(__s); }
+      { rdbuf()->str(__s); }
     };
 
   typedef basic_stringstream<char> stringstream;
@@ -336,8 +351,10 @@ namespace std {
 
 #ifdef _GLIBCPP_NO_TEMPLATE_EXPORT
 # define export
+#ifdef  _GLIBCPP_FULLY_COMPLIANT_HEADERS
 # include <bits/sstream.tcc>
 #endif
+#endif
 
 
 #endif	/* _CPP_SSTREAM */
@@ -350,3 +367,8 @@ namespace std {
 
 
 
+
+
+
+
+
