@@ -1,6 +1,6 @@
 /* Complex sine function for double. */
 
-/* Copyright (C) 1997-1999 Cygnus Solutions
+/* Copyright (C) 1997-1999 Free Software Foundation, Inc.
 
    This file is part of the GNU ISO C++ Library.  This library is free
    software; you can redistribute it and/or modify it under the
@@ -78,7 +78,7 @@ csin (__complex__ double x)
       if (__real__ x == 0.0)
 	{
 	  /* Real part is 0.0.  */
-	  __real__ retval = __copysign (0.0, negate ? -1.0 : 1.0);
+	  __real__ retval = copysign (0.0, negate ? -1.0 : 1.0);
 	  __imag__ retval = __imag__ x;
 	}
       else if (FINITE_P (__real__ x))
@@ -87,8 +87,8 @@ csin (__complex__ double x)
 	  double sinix = sin (__real__ x);
 	  double cosix = cos (__real__ x);
 
-	  __real__ retval = __copysign (HUGE_VAL, sinix);
-	  __imag__ retval = __copysign (HUGE_VAL, cosix);
+	  __real__ retval = copysign (HUGE_VAL, sinix);
+	  __imag__ retval = copysign (HUGE_VAL, cosix);
 
 	  if (negate)
 	    __real__ retval = -__real__ retval;
@@ -105,7 +105,7 @@ csin (__complex__ double x)
   else
     {
       if (__real__ x == 0.0)
-	__real__ retval = __copysign (0.0, negate ? -1.0 : 1.0);
+	__real__ retval = copysign (0.0, negate ? -1.0 : 1.0);
       else
 	__real__ retval = NAN;
       __imag__ retval = NAN;
