@@ -1,8 +1,8 @@
-#include <config.h>
-#ifdef HAVE_SINL
+#include <bits/c++config.h>
+#ifdef _GLIBCPP_HAVE_SINL
 /* We compile these functions only when we have the long double functions
    available.  */
 #define FLT long double
-#define FCT(name) name##l
+#define FCT(name) ::name##l
 #include "complex.cc"
 #endif
