@@ -1,6 +1,6 @@
 // Explicit instantiation file.
 
-// Copyright (C) 1997-1999 Cygnus Solutions
+// Copyright (C) 1997-1999 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -40,9 +40,19 @@
 #include <bits/std_sstream.h>
 #include <bits/std_fstream.h>
 #include <bits/std_ios.h>
+#include <bits/basic_ios.tcc>
 #include <bits/std_istream.h>
 #include <bits/std_ostream.h>
 
+// NB: unnecessary if the .h headers include these
+#ifndef  _GLIBCPP_FULLY_COMPLIANT_HEADERS
+#include <bits/sstream.tcc>
+#include <bits/fstream.tcc>
+#include <bits/streambuf.tcc>
+#include <bits/istream.tcc>
+#include <bits/ostream.tcc>
+#endif
+
 namespace std {
 
   //
@@ -86,9 +96,17 @@ namespace std {
   //
   template class basic_istream<char>;
   template istream& ws(istream&);
+  template istream& operator>>(istream&, char&);
+  template istream& operator>>(istream&, unsigned char&);
+  template istream& operator>>(istream&, signed char&);
+  template istream& operator>>(istream&, char*);
+  template istream& operator>>(istream&, unsigned char*);
+  template istream& operator>>(istream&, signed char*);
 #ifdef _GLIBCPP_USE_WCHAR_T
   template class basic_istream<wchar_t>;
   template wistream& ws(wistream&);
+  template wistream& operator>>(wistream&, wchar_t&);
+  template wistream& operator>>(wistream&, wchar_t*);
 #endif
 
 
@@ -99,7 +117,12 @@ namespace std {
   template ostream& endl(ostream&);
   template ostream& ends(ostream&);
   template ostream& flush(ostream&);
+  template ostream& operator<<(ostream&, char);
+  template ostream& operator<<(ostream&, unsigned char);
+  template ostream& operator<<(ostream&, signed char);
   template ostream& operator<<(ostream&, const char*);
+  template ostream& operator<<(ostream&, const unsigned char*);
+  template ostream& operator<<(ostream&, const signed char*);
   // template ostream& operator<<(ostream&, _Setfill<char>);
   // template ostream& operator<<(ostream&, _Setw);
   // template _Setfill<char> setfill(char);
@@ -108,13 +131,25 @@ namespace std {
   template wostream& endl(wostream&);
   template wostream& ends(wostream&);
   template wostream& flush(wostream&);
+  template wostream& operator<<(wostream&, wchar_t);
+  template wostream& operator<<(wostream&, char);
   template wostream& operator<<(wostream&, const wchar_t*);
+  template wostream& operator<<(wostream&, const char*);
   // template wostream& operator<<(wostream&, _Setfill<wchar_t>);
   // template wostream& operator<<(wostream&, _Setw);
   // template _Setfill<wchar_t> setfill(wchar_t);
 #endif
   
 
+  //
+  // iostream
+  //
+  template class basic_iostream<char>;
+#ifdef _GLIBCPP_USE_WCHAR_T
+  template class basic_iostream<wchar_t>; 
+#endif
+
+
   //
   // istringstream
   //
@@ -153,8 +188,8 @@ namespace std {
   
   template 
     string* 
-    __uninitialized_fill_n_aux<string*, unsigned int, string>
-    (string*, unsigned int, string const &, _Bool<false>);
+    __uninitialized_fill_n_aux<string*, size_t, string>
+    (string*, size_t, string const &, _Bool<false>);
 
   template 
     string* 
