@@ -233,7 +233,7 @@
 
 
 # ifdef __GNUC__
-#   include <_G_config.h>
+//#   include <_G_config.h>
 #   define __STL_HAS_WCHAR_T
 #   if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 8)
 #     define __STL_STATIC_TEMPLATE_MEMBER_BUG
@@ -245,41 +245,26 @@
 #     define __STL_CLASS_PARTIAL_SPECIALIZATION 
 #     define __STL_PARTIAL_SPECIALIZATION_SYNTAX 
 #     define __STL_FUNCTION_TMPL_PARTIAL_ORDER
-//#     define __STL_CAN_THROW_RANGE_ERRORS // till stdexception sorted out
 #     define __STL_EXPLICIT_FUNCTION_TMPL_ARGS
 #     define __SGI_STL_USE_AUTO_PTR_CONVERSIONS
 #     define __STL_HAS_NAMESPACES
 #     define __STL_USE_NAMESPACES
 #     define __STL_USE_EXCEPTIONS
+#     define __STL_CAN_THROW_RANGE_ERRORS 
 #     define __STL_USE_STD_ALLOCATORS 
 #     define __USE_MALLOC // As the "underlying allocator"
 //#     define __STL_USE_NEW_IOSTREAMS //990209 bkoz--use standard .h includes.
 #   endif
-    /* glibc pre 2.0 is very buggy. We have to disable threads for it.
-       It should be upgraded to glibc 2.0 or later. */
-// 990209 bkoz disable temporarily untill we have makefile support for
-// --enable-threads
-#if 0
-#   if !defined(_NOTHREADS) && __GLIBC__ >= 2 && defined(_G_USING_THUNKS)
+#   ifdef _PTHREADS
 #     define __STL_THREADS
-#     define _PTHREADS
 #     define __STL_PTHREADS
-#     ifdef __STRICT_ANSI__
-        /* Work around a bug in the glibc 2.0.x pthread.h.  */
-#       define sigset_t __sigset_t
-#     endif
 #   endif
-#endif 
-// 990209 bkoz
 #   ifdef __EXCEPTIONS
 #     define __STL_USE_EXCEPTIONS
 #   endif
-/// 1998-10-27 ncm, support for long long elsewhere is not ready yet. 
-#if 0
 #   ifndef __STRICT_ANSI__
 #     define __STL_LONG_LONG
 #   endif
-#endif
 # endif
 
 # if defined(__SUNPRO_CC) 
