@@ -1,7 +1,7 @@
 // 1999-06-05
 // Gabriel Dos Reis <dosreis@cmla.ens-cachan.fr>
 
-// Copyright (C) 1999 Free Software Foundation, Inc.
+// Copyright (C) 2000, 1999 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -20,6 +20,7 @@
 // USA.
 
 #include <cmath>
+#include <cassert>
 
 // test compilation.
 void test01()
@@ -41,10 +42,20 @@ void test03()
   double powtest = pow(2., 0);
 }
 
+// this used to abort.
+void test04()
+{
+  float x[2] = {1, 2};
+  float y = 3.4;
+  std::modf(y, &x[0]);
+  assert (x[1] == 2);
+}
+
 int main()
 {
-    test01();
-    test02();
-    test03();
-    return 0;
+  test01();
+  test02();
+  test03();
+  test04();
+  return 0;
 }
