@@ -1,6 +1,6 @@
 // 990117 bkoz test functionality of basic_filebuf for char_type == char
 
-// Copyright (C) 1997-1999 Cygnus Solutions
+// Copyright (C) 1997-1999 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -19,8 +19,8 @@
 // USA.
 
 // NB: this test assumes that _M_buf_size == 40, and not the usual
-// BUFSIZ length of 8092, so that overflow/underflow can be simulated
-// a bit more readily.
+// buffer_size length of 8092, so that overflow/underflow can be
+// simulated a bit more readily.
 
 #include <fstream>
 #ifdef DEBUG_ASSERT
@@ -33,10 +33,26 @@ const char name_01[] = "testsuite/filebuf-1.txt"; // file with data in it
 const char name_02[] = "testsuite/filebuf-2.txt"; // empty file, need to create
 const char name_03[] = "testsuite/filebuf-3.txt"; // empty file, need to create
 
-std::filebuf fb_01; // in 
-std::filebuf fb_02; // out
-std::filebuf fb_03; // in | out
+class derived_filebuf: public std::filebuf
+{
+ public:
+  void
+  set_size(int_type __size) { _M_buf_size = __size; }
+};
 
+derived_filebuf fb_01; // in 
+derived_filebuf fb_02; // out
+derived_filebuf fb_03; // in | out
+
+const int buffer_size = 8192;
+
+// initialize filebufs to be the same size regardless of platform
+void test00()
+{
+  fb_01.set_size(buffer_size);
+  fb_02.set_size(buffer_size);
+  fb_03.set_size(buffer_size);
+}
 
 // test the filebuf/stringbuf locale settings
 bool test01() {
@@ -91,13 +107,13 @@ bool test03() {
   typedef std::filebuf::traits_type 	traits_type;
   typedef std::filebuf::pos_type 	pos_type;
   typedef std::filebuf::off_type 	off_type;
-  typedef size_t 		size_type;
+  typedef size_t 			size_type;
 
-  bool 			test = true;
-  std::filebuf 		f_tmp;
-  std::streamsize 		strmsz_1, strmsz_2;
-  std::streamoff  		strmof_1, strmof_2;
-  int 			i = 0, j = 0, k = 0;
+  bool 					test = true;
+  std::filebuf 				f_tmp;
+  std::streamsize 			strmsz_1, strmsz_2;
+  std::streamoff  			strmof_1, strmof_2;
+  int 					i = 0, j = 0, k = 0;
 
   // GET
   // int showmanyc()
@@ -182,7 +198,7 @@ bool test03() {
   test = strmsz_1 != strmsz_2;
   char carray1[13] = "";
   strmsz_1 = fb_01.sgetn(carray1, 10);
-  char carray2[BUFSIZ] = "";
+  char carray2[buffer_size] = "";
   strmsz_2 = fb_02.sgetn(carray2, 10);
   test &= strmsz_1 != strmsz_2;
   test &= strmsz_1 == 10;
@@ -489,6 +505,7 @@ bool test03() {
 
 
 int main() {
+  test00();
   test01();
   test02();
   test03();
@@ -506,3 +523,6 @@ int main() {
 
 
 
+
+
+
